Skip to contents

This function computes the contribution if each item during stages, based on the Fisher information.

Usage

IRT4Sselecting(D, proj)

Arguments

D

an object of class jointLPM representing the estimated dimension model with the items

proj

a vector

Value

a list of two matrices

###@examples

References

preprint : arXiv:2407.08278

Author

Tiphaine Saulnier, Viviane Philipps and Cecile Proust-Lima