Skip to contents

This function provides a brief summary of model estimated with the jointLPM function.

Usage

# S3 method for class 'jointLPM'
print(x, ...)

Arguments

x

an object inheriting from class jointLPM for a joint latent process model.

...

further arguments to be passed to or from other methods. They are ignored in this function.

Value

the function is used for its side effects, no value is returned.

Author

Viviane Philipps, Tiphaine Saulnier and Cecile Proust-Lima