This function provides a summary of model estimated with the jointLPM function.
Usage
# S3 method for class 'jointLPM'
summary(object, ...)Value
The function is mainly used for its side effects. It returns invisibily a list of two matrices containing the estimates, their standard errors, Wald statistics and associated p-values for the survival submodel (first element of the list) and for the mixed model's fixed effects (second element).