The random effects of a jointLPM model are predicted as the mode of
the conditional distribution of the random effects given the subject's
longitudinal and survival observations.
Arguments
- x
a
jointLPMobject- data
a data.frame object containing the data from the predictions are to be computed
- control
optional list of arguments to be passed to the
marqLevAlgoptimization function.- variance
logical indicating whether the variance of the estimated predictions should be returned. Default ot FALSE.