This function provides a brief summary of model estimated with the jointLPM function.
Usage
# S3 method for class 'jointLPM'
print(x, ...)This function provides a brief summary of model estimated with the jointLPM function.
# S3 method for class 'jointLPM'
print(x, ...)